﻿using System;
using System.Windows.Controls;
using System.Windows.Navigation;
using SilverlightS3.Util;

namespace SilverlightS3.Views
{
    /// <summary>
    /// バケット一覧画面のコードビハインドクラスです。
    /// </summary>
    public partial class BucketList : Page
    {
        /// <summary>
        /// コンストラクタです。
        /// </summary>
        public BucketList()
        {
            InitializeComponent();
            Header.ListBucketsButton.Click += new System.Windows.RoutedEventHandler(ListBucketsButton_Click);
        }

        /// <summary>
        /// このページに移動したときに実行されます。
        /// </summary>
        /// <param name="e">NavigationEventArgsオブジェクトです。</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            DateTime timeStamp = S3Helper.GetDatestamp();

            AWSS3.AmazonS3Client s3 = S3Util.getS3();

            s3.ListAllMyBucketsCompleted += new EventHandler<AWSS3.ListAllMyBucketsCompletedEventArgs>(s3_ListAllMyBucketsCompleted);
            s3.ListAllMyBucketsAsync(S3Util.AWS_AWS_ID, timeStamp, 
                S3Helper.GenerateSignature(S3Util.AWS_SECRET_KEY, S3Util.S3_OPERATION_LIST_ALL_MY_BUCKETS, timeStamp));
        }

        /// <summary>
        /// バケット一覧取得処理の完了イベントです。
        /// </summary>
        /// <param name="sender">イベントのソースです。</param>
        /// <param name="e">バケット一覧取得処理のデータを格納しているオブジェクトです。</param>
        void s3_ListAllMyBucketsCompleted(object sender, AWSS3.ListAllMyBucketsCompletedEventArgs e)
        {
            if (e.Error == null)
            {
                AWSS3.ListAllMyBucketsResult res = e.Result;
                AWSS3.ListAllMyBucketsEntry[] buckets = res.Buckets;
                BucketDataGrid.ItemsSource = buckets;
            }
        }

        /// <summary>
        /// バケットDataGridの選択行変更イベントです。
        /// </summary>
        /// <param name="sender">イベントのソースです。</param>
        /// <param name="e">イベント データを格納している EventArgsです。</param>
        private void BucketDataGrid_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            DateTime timeStamp = S3Helper.GetDatestamp();
            AWSS3.ListAllMyBucketsEntry selectedBucket = BucketDataGrid.SelectedItem as AWSS3.ListAllMyBucketsEntry;
            string bucketName = selectedBucket.Name;

            Uri contentListPageUri = new Uri(String.Format("/Views/ContentList.xaml?bucketName=" + bucketName), UriKind.Relative);

            NavigationService.Navigate(contentListPageUri);
        }

        /// <summary>
        /// ヘッダー：バケット一覧表示ボタンのクリックイベントです。
        /// </summary>
        /// <param name="sender">イベントのソースです。</param>
        /// <param name="e">イベント データを格納している EventArgsです。</param>
        private void ListBucketsButton_Click(object sender, EventArgs e)
        {
            Header.navigateToBucketList(NavigationService);
        }
    }
}
