﻿using System;
using System.Linq;
using System.Windows.Controls;
using System.Windows.Navigation;
using SilverlightS3.Util;

namespace SilverlightS3.Views
{
    /// <summary>
    /// コンテンツ一覧画面のコードビハインドクラスです。
    /// </summary>
    public partial class ContentList : Page
    {
        /// <summary>
        /// コンストラクタです。
        /// </summary>
        public ContentList()
        {
            InitializeComponent();
            Header.ListBucketsButton.Click += new System.Windows.RoutedEventHandler(ListBucketsButton_Click);
        }

        /// <summary>
        /// このページに移動したときに実行されます。
        /// </summary>
        /// <param name="e">NavigationEventArgsオブジェクトです。</param>
        protected override void OnNavigatedTo(NavigationEventArgs e)
        {
            if (this.NavigationContext.QueryString.ContainsKey("bucketName"))
            {
                string bucketName = this.NavigationContext.QueryString["bucketName"];

                DateTime timeStamp = S3Helper.GetDatestamp();

                AWSS3.AmazonS3Client s3 = S3Util.getS3();

                s3.ListBucketCompleted += new EventHandler<SilverlightS3.AWSS3.ListBucketCompletedEventArgs>(s3_ListBucketCompleted);
                s3.ListBucketAsync(bucketName, null, null, 1000, null, S3Util.AWS_AWS_ID, timeStamp, 
                    S3Helper.GenerateSignature(S3Util.AWS_SECRET_KEY, S3Util.S3_OPERATION_LIST_BUCKET, timeStamp), null, null);

                Header.BucketNameTextBox.Text = bucketName;
            }
        }

        /// <summary>
        /// オブジェクト一覧取得処理の完了イベントです。
        /// </summary>
        /// <param name="sender">イベントのソースです。</param>
        /// <param name="e">オブジェクト一覧取得処理のデータを格納しているオブジェクトです。</param>
        void s3_ListBucketCompleted(object sender, AWSS3.ListBucketCompletedEventArgs e)
        {
            if (e.Error == null)
            {
                AWSS3.ListBucketResult res = e.Result;
                
                AWSS3.ListEntry[] originalContents = res.Contents;

                var queryResult = from content in originalContents
                                    where content.Key != "clientaccesspolicy.xml"
                                    orderby content.Key
                                    select content;

                AWSS3.ListEntry[] contents = queryResult.ToArray();

                ContentDataGrid.ItemsSource = contents;
            }
        }

        /// <summary>
        /// ヘッダー：バケット一覧表示ボタンのクリックイベントです。
        /// </summary>
        /// <param name="sender">イベントのソースです。</param>
        /// <param name="e">イベント データを格納している EventArgsです。</param>
        private void ListBucketsButton_Click(object sender, EventArgs e)
        {
            Header.navigateToBucketList(NavigationService);
        }
    }
}
